package org.tbasket

import org.tbasket.api.Endpoint
import org.tbasket.compute.IncrementHandler

import java.util.Properties

object EndpointSetup {

    final val EndpointUrl        = "endpoint.url"
    final val EndpointUrlDefault = s"localhost:48485"

    def setupEndpoint(): Endpoint = {
        Main.LOG.debug("Initializing API endpoint...")
        val endpoint = createEndpoint()
        endpoint.bind("counter")(IncrementHandler)
        endpoint
    }

    private def createEndpoint(): Endpoint = {
        val properties = new Properties()
        val in         = getClass.getClassLoader.getResourceAsStream("server.properties")
        properties.load(in)
        val (hostname, port) = properties
                .getProperty(EndpointUrl, EndpointUrlDefault) match {
            case s"$ip:$port" => (ip, port.toInt)
            case v            => throw new InternalBasketServerException(s"$EndpointUrl property value is wrong: $v must be <ip>:<port>/[endpointPath]")
        }
        new Endpoint(hostname, port)
    }

}
